/*
 * de405.c - readout DE405/406 ephemerides
 *  Copyright (C) 2002-2005 Noriaki TANAKA (dtana@startide.jp)
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 *  02111-1307, USA.
 *
 * $Id: de405.h,v 1.20 2005/05/08 11:02:49 dtana Exp $
 */
#ifndef DE405_H
#define DE405_H

#include <stdio.h>

enum {
	DE_MERCURY = 0,
	DE_VENUS,
	DE_EARTH_MOON_BARYCENTER,
	DE_MARS,
	DE_JUPITER,
	DE_SATURN,
	DE_URANUS,
	DE_NEPTUNE,
	DE_PLUTO,
	DE_MOON,
	DE_SUN,
	DE_NUTATIONS,
	DE_LIBRATIONS
};

typedef struct {
	FILE *fp;

	char title[3][84 + 1];
	int nconstants;
	struct {
		char name[6 + 1];
		double c;
	}  constant[400];
	struct ipt_t {
		int offset;
		int ncf; /* number of coefficients */
		int ncm; /* number of components (3 or 2) */
		double na; /* number of sets of coefficents */
	} ipt[13];

	double bjd, ejd, step; /* time span */
	double au, AU;	       /* AU (in km), km to AU */
	double emratio;	       /* mass ratio Earth/Moon */

	int denum;	       /* 200, 403, 404, 405 or 406 */
	int ndata;             /* number of elements per record */

	/* current buffer */
	double *eb;
	long nr; /* current record number */
} DE405;

DE405 *de405_open(const char *);
int de405_ephem(DE405 *, double, int, double [3], double [3]);
int de405_ephem_earth(DE405 *, double, double [3], double [3]);
void de405_close(DE405 *);
double de405_constant(DE405 *, const char *);

#endif
